@@ -21,6 +21,7 @@ class CGraph {
 	
     private $data;
     private $data_type = array('pie' => 'text-data-single', 'bars' => 'text-data');
+	private $data_colors = array( 'blue', 'orange', 'purple', 'red', 'green', 'SkyBlue', 'yellow', 'cyan', 'lavender', 'DimGrey');
     private $graph_type;
 	
     private $width;
@@ -39,7 +40,7 @@ class CGraph {
     }
 
     public function SetGraphSize($width, $height) {
-        $this->width = $width;
+        $this->width  = $width;
         $this->height = $height;
     }
 
@@ -73,7 +74,23 @@ class CGraph {
 		$this->plot->SetLegendPixels($this->width - ($legend_width + 5), 10);	
 	}
 	
-    public function Render() {
+    // ==================================================================================
+	// Function: 	Render()
+	// Parameters:	none
+	// Return:		graph image file path
+	// ==================================================================================
+	
+	public function setPieLegendColors( $colors = array() ) {
+		$this->data_colors = $colors;
+	}
+
+    // ==================================================================================
+	// Function: 	Render()
+	// Parameters:	none
+	// Return:		graph image file path
+	// ==================================================================================
+	
+	public function Render() {
         // Setting the size
         $this->plot = new PHPlot($this->width, $this->height);
 
@@ -89,7 +106,7 @@ class CGraph {
 		// Set graph values
 		$this->plot->SetDataValues($this->data);
 		
-		// Check if provided datas for the graph are a valid and non empty array
+		// Check if provided datas for the graph are a valid and non empty array (to be improved)
 		if( is_null($this->data) or empty($this->data) ) {
 			$message_options = array( 'draw_background' => TRUE, 'draw_border' => TRUE, 'reset_font' => TRUE, 'text_color' => 'black' );
 			$this->plot->DrawMessage('No statistics to display', $message_options);
@@ -99,16 +116,18 @@ class CGraph {
 
 			switch ( $this->graph_type ) {
 				case 'pie':
+					$plot_padding = 0;
+
 					// Set legend
 					$this->setLegend();
 					
-					$this->plot->SetPlotAreaPixels(5, 5, ($this->width / 2), $this->height - 5);
-					$this->plot->SetLabelScalePosition(0.2);
+					// Set plot area
+					$this->plot->SetPlotAreaPixels($plot_padding, $plot_padding, ($this->width * 0.65), $this->height-$plot_padding);
 
 					// Set graph colors and shading
-					$data_colors = array( 'blue', 'green', 'orange', 'red', 'black', 'yellow', 'cyan', 'lavender', 'DimGrey');
-					$this->plot->SetDataColors( $data_colors );
+					$this->plot->SetDataColors( $this->data_colors );
 					$this->plot->SetShading( 0 );
+					$this->plot->SetLabelScalePosition(0.5);
 					
 					break;
 				case 'bars':
